echo_ring_ptr

Function echo_ring_ptr 

pub unsafe fn echo_ring_ptr(ptr: *mut u8) -> *mut ParameterEvent
Returns a pointer to the echo ring buffer slot array.

Safety

ptr must point to a valid allocation large enough to contain the echo ring.